@@ -7,7 +7,7 @@ use POE::Component::IRC::Common qw(u_irc parse_mode_line parse_ban_mask);
 use POE::Component::IRC::Plugin qw(PCI_EAT_NONE);
 use base qw(POE::Component::IRC);
 
-our $VERSION = '6.06';
+our $VERSION = '6.10';
 
 # Event handlers for tracking the STATE. $self->{STATE} is used as our
 # namespace. u_irc() is used to create unique keys.
@@ -18,6 +18,7 @@ our $VERSION = '6.06';
 sub S_001 {
     my ($self) = @_;
     delete $self->{STATE};
+    delete $self->{NETSPLIT};
     $self->{STATE}->{usermode} = '';
     $self->yield(mode => $self->nick_name());
     return PCI_EAT_NONE;
@@ -77,6 +78,17 @@ sub S_join {
         }
     }
     else {
+      SWITCH: {
+        my $netsplit = "$unick!$user\@$host";
+        if ( exists $self->{NETSPLIT}->{Users}->{ $netsplit } ) {
+            # restore state from NETSPLIT if it hasn't expired.
+            my $nuser = delete $self->{NETSPLIT}->{Users}->{ $netsplit };
+            if ( ( time - $nuser->{stamp} ) < ( 60 * 60 ) ) {
+              $self->{STATE}->{Nicks}->{ $unick } = $nuser->{meta};
+              $self->_send_event(irc_nick_sync => $nick, $chan);
+              last SWITCH;
+            }
+        }
         if ( (!exists $self->{whojoiners} || $self->{whojoiners})
             && !exists $self->{STATE}->{Nicks}->{ $unick }->{Real}) {
                 $self->yield(who => $nick);
@@ -86,6 +98,7 @@ sub S_join {
             # Fake 'irc_nick_sync'
             $self->_send_event(irc_nick_sync => $nick, $chan);
         }
+      }
     }
 
     $self->{STATE}->{Nicks}->{ $unick }->{Nick} = $nick;
@@ -133,33 +146,42 @@ sub S_quit {
     my $nick  = (split /!/, ${ $_[0] })[0];
     my $msg   = ${ $_[1] };
     my $unick = u_irc($nick, $map);
+    my $netsplit = 0;
 
     push @{ $_[-1] }, [ $self->nick_channels( $nick ) ];
 
     # Check if it is a netsplit
-#    if ($msg) {
-#        SWITCH: {
-#            my @args = split /\x20/, $msg;
-#            if ( @args != 2 ) {
-#                last SWITCH;
-#           }
-#        }
-#    }
+    $netsplit = 1 if _is_netsplit( $msg );
 
     if ($unick eq u_irc($self->nick_name(), $map)) {
         delete $self->{STATE};
+        delete $self->{NETSPLIT};
     }
     else {
         for my $uchan ( keys %{ $self->{STATE}->{Nicks}->{ $unick }->{CHANS} } ) {
             delete $self->{STATE}->{Chans}->{ $uchan }->{Nicks}->{ $unick };
+            # No don't stash the channel state.
+            #$self->{NETSPLIT}->{Chans}->{ $uchan }->{NICKS}->{ $unick } = $chanstate
+            #  if $netsplit;
         }
         
-        delete $self->{STATE}->{Nicks}->{ $unick };
+        my $nickstate = delete $self->{STATE}->{Nicks}->{ $unick };
+        if ( $netsplit ) {
+          delete $nickstate->{CHANS};
+          $self->{NETSPLIT}->{Users}->{ "$unick!" . join '@', @{$nickstate}{qw(User Host)} } = 
+             { meta => $nickstate, stamp => time };
+        }
     }
 
     return PCI_EAT_NONE;
 }
 
+sub _is_netsplit {
+  my $msg = shift || return;
+  return 1 if $msg =~ /^\s*\S+\.[a-z]{2,} \S+\.[a-z]{2,}$/i;
+  return 0;
+}
+
 sub S_kick {
     my ($self, $irc) = splice @_, 0, 2;
     my $chan  = ${ $_[1] };
@@ -378,6 +400,38 @@ sub S_topic {
     return PCI_EAT_NONE;  
 }
 
+# RPL_NAMES
+sub S_353 {
+    my ($self, $irc) = splice @_, 0, 2;
+    my @data = @{ ${ $_[2] } };
+    shift @data if $data[0] =~ /^(\x40|\x2A|\x3D)$/;
+    my $chan = shift @data;
+    my @nicks = split /\s+/, shift @data;
+    my $map   = $irc->isupport('CASEMAPPING');
+    my $uchan = u_irc($chan, $map);
+    my $prefix = $irc->isupport('PREFIX') || { o => '@', v => '+' };
+    my $search = join '|', map { quotemeta } values %$prefix;
+    foreach my $user ( @nicks ) {
+       my $status;
+       if ( ($status) = $user =~ /^($search)/ ) {
+          $user =~ s/^($search)//g;
+       }
+       $status = '' unless $status;
+       my $whatever = '';
+       my $unick = u_irc($user,$map);
+       my $existing = $self->{STATE}->{Nicks}->{ $unick }->{CHANS}->{ $uchan } || '';
+       for my $mode ( keys %{ $prefix } ) {
+         if ($status =~ /\Q$prefix->{$mode}/ && $existing !~ /\Q$prefix->{$mode}/ ) {
+           $whatever .= $mode;
+         }
+       }
+       $existing .= $whatever if !$existing || $existing !~ /$whatever/;
+       $self->{STATE}->{Nicks}->{ $unick }->{CHANS}->{ $uchan } = $existing;
+       $self->{STATE}->{Chans}->{ $uchan }->{Nicks}->{ $unick } = $existing;
+    }
+    return PCI_EAT_NONE;  
+}
+
 # RPL_WHOREPLY
 sub S_352 {
     my ($self, $irc) = splice @_, 0, 2;
@@ -405,7 +459,7 @@ sub S_352 {
     if ( exists $self->{STATE}->{Chans}->{ $uchan } ) {
         my $whatever = '';
         my $existing = $self->{STATE}->{Nicks}->{ $unick }->{CHANS}->{ $uchan } || '';    
-        my $prefix = $irc->isupport('PREFIX') || { o =>, '@', v => '+' };
+        my $prefix = $irc->isupport('PREFIX') || { o => '@', v => '+' };
 
         for my $mode ( keys %{ $prefix } ) {
             if ($status =~ /\Q$prefix->{$mode}/ && $existing !~ /\Q$prefix->{$mode}/ ) {
@@ -1434,7 +1488,7 @@ The component gathers information by registering for C<irc_quit>, C<irc_nick>,
 C<irc_join>, C<irc_part>, C<irc_mode>, C<irc_kick> and various numeric replies.
 When the component is asked to join a channel, when it joins it will issue
 'WHO #channel', 'MODE #channel', and 'MODE #channel b'. These will solicit
-between them the numerics, >C<irc_352>, C<irc_324> and C<irc_329>, respectively.
+between them the numerics, C<irc_352>, C<irc_324> and C<irc_329>, respectively.
 When someone joins a channel the bot is on, it issues a 'WHO nick'. You may
 want to ignore these. 
 
